@@ -1,4 +1,3 @@
-from __future__ import print_function
 import os
 
 from burlap import common
@@ -9,7 +8,7 @@ CURRENT_DIR = os.path.abspath(os.path.dirname(__file__))
 class DebugTests(TestCase):
 
     def setUp(self):
-        super(DebugTests, self).setUp()
+        super().setUp()
 
         common.set_verbose(True)
         # Ensure we're in burlap's root directory.
